# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/group_mapping_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.organizationmanager.v1 import group_mapping_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/group_mapping_service.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?yandex/cloud/organizationmanager/v1/group_mapping_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x37yandex/cloud/organizationmanager/v1/group_mapping.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\"=\n\x16GetGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x17GetGroupMappingResponse\x12H\n\rgroup_mapping\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.GroupMapping\"Q\n\x19\x43reateGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"3\n\x1a\x43reateGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x8b\x01\n\x19UpdateGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0eupdated_fields\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"3\n\x1aUpdateGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"@\n\x19\x44\x65leteGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x1a\x44\x65leteGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\xb0\x01\n\x1eUpdateGroupMappingItemsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12i\n\x19group_mapping_item_deltas\x18\x04 \x03(\x0b\x32:.yandex.cloud.organizationmanager.v1.GroupMappingItemDeltaB\n\x82\xc8\x31\x06\x31-1000\"\xe6\x01\n\x15GroupMappingItemDelta\x12\x43\n\x04item\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.GroupMappingItem\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.organizationmanager.v1.GroupMappingItemDelta.Action\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\"8\n\x1fUpdateGroupMappingItemsMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x80\x01\n\x1fUpdateGroupMappingItemsResponse\x12]\n\x19group_mapping_item_deltas\x18\x04 \x03(\x0b\x32:.yandex.cloud.organizationmanager.v1.GroupMappingItemDelta\"\x9e\x01\n\x1cListGroupMappingItemsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x8c\x01\n\x1dListGroupMappingItemsResponse\x12R\n\x13group_mapping_items\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.GroupMappingItem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd0\x07\n\x13GroupMappingService\x12\x80\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.GetGroupMappingRequest\x1a<.yandex.cloud.organizationmanager.v1.GetGroupMappingResponse\x12\x9b\x01\n\x06\x43reate\x12>.yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\".\xb2\xd2**\n\x1a\x43reateGroupMappingMetadata\x12\x0cGroupMapping\x12\x9b\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\".\xb2\xd2**\n\x1aUpdateGroupMappingMetadata\x12\x0cGroupMapping\x12\xa4\x01\n\x06\x44\x65lete\x12>.yandex.cloud.organizationmanager.v1.DeleteGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\"7\xb2\xd2*3\n\x1a\x44\x65leteGroupMappingMetadata\x12\x15google.protobuf.Empty\x12\x92\x01\n\tListItems\x12\x41.yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest\x1a\x42.yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse\x12\xbd\x01\n\x0bUpdateItems\x12\x43.yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*B\n\x1fUpdateGroupMappingItemsMetadata\x12\x1fUpdateGroupMappingItemsResponseB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])



_GROUPMAPPINGITEMDELTA_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='yandex.cloud.organizationmanager.v1.GroupMappingItemDelta.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1271,
  serialized_end=1324,
)
_sym_db.RegisterEnumDescriptor(_GROUPMAPPINGITEMDELTA_ACTION)


_GETGROUPMAPPINGREQUEST = _descriptor.Descriptor(
  name='GetGroupMappingRequest',
  full_name='yandex.cloud.organizationmanager.v1.GetGroupMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.GetGroupMappingRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=361,
)


_GETGROUPMAPPINGRESPONSE = _descriptor.Descriptor(
  name='GetGroupMappingResponse',
  full_name='yandex.cloud.organizationmanager.v1.GetGroupMappingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_mapping', full_name='yandex.cloud.organizationmanager.v1.GetGroupMappingResponse.group_mapping', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=462,
)


_CREATEGROUPMAPPINGREQUEST = _descriptor.Descriptor(
  name='CreateGroupMappingRequest',
  full_name='yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest.enabled', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=545,
)


_CREATEGROUPMAPPINGMETADATA = _descriptor.Descriptor(
  name='CreateGroupMappingMetadata',
  full_name='yandex.cloud.organizationmanager.v1.CreateGroupMappingMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.CreateGroupMappingMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=598,
)


_UPDATEGROUPMAPPINGREQUEST = _descriptor.Descriptor(
  name='UpdateGroupMappingRequest',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_fields', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest.updated_fields', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=740,
)


_UPDATEGROUPMAPPINGMETADATA = _descriptor.Descriptor(
  name='UpdateGroupMappingMetadata',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=742,
  serialized_end=793,
)


_DELETEGROUPMAPPINGREQUEST = _descriptor.Descriptor(
  name='DeleteGroupMappingRequest',
  full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMappingRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=859,
)


_DELETEGROUPMAPPINGMETADATA = _descriptor.Descriptor(
  name='DeleteGroupMappingMetadata',
  full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMappingMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMappingMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=912,
)


_UPDATEGROUPMAPPINGITEMSREQUEST = _descriptor.Descriptor(
  name='UpdateGroupMappingItemsRequest',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_mapping_item_deltas', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest.group_mapping_item_deltas', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0061-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=915,
  serialized_end=1091,
)


_GROUPMAPPINGITEMDELTA = _descriptor.Descriptor(
  name='GroupMappingItemDelta',
  full_name='yandex.cloud.organizationmanager.v1.GroupMappingItemDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='yandex.cloud.organizationmanager.v1.GroupMappingItemDelta.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.organizationmanager.v1.GroupMappingItemDelta.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPMAPPINGITEMDELTA_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1324,
)


_UPDATEGROUPMAPPINGITEMSMETADATA = _descriptor.Descriptor(
  name='UpdateGroupMappingItemsMetadata',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1382,
)


_UPDATEGROUPMAPPINGITEMSRESPONSE = _descriptor.Descriptor(
  name='UpdateGroupMappingItemsResponse',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_mapping_item_deltas', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsResponse.group_mapping_item_deltas', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1513,
)


_LISTGROUPMAPPINGITEMSREQUEST = _descriptor.Descriptor(
  name='ListGroupMappingItemsRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1516,
  serialized_end=1674,
)


_LISTGROUPMAPPINGITEMSRESPONSE = _descriptor.Descriptor(
  name='ListGroupMappingItemsResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_mapping_items', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse.group_mapping_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1817,
)

_GETGROUPMAPPINGRESPONSE.fields_by_name['group_mapping'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2._GROUPMAPPING
_UPDATEGROUPMAPPINGREQUEST.fields_by_name['updated_fields'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['group_mapping_item_deltas'].message_type = _GROUPMAPPINGITEMDELTA
_GROUPMAPPINGITEMDELTA.fields_by_name['item'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2._GROUPMAPPINGITEM
_GROUPMAPPINGITEMDELTA.fields_by_name['action'].enum_type = _GROUPMAPPINGITEMDELTA_ACTION
_GROUPMAPPINGITEMDELTA_ACTION.containing_type = _GROUPMAPPINGITEMDELTA
_UPDATEGROUPMAPPINGITEMSRESPONSE.fields_by_name['group_mapping_item_deltas'].message_type = _GROUPMAPPINGITEMDELTA
_LISTGROUPMAPPINGITEMSRESPONSE.fields_by_name['group_mapping_items'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2._GROUPMAPPINGITEM
DESCRIPTOR.message_types_by_name['GetGroupMappingRequest'] = _GETGROUPMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['GetGroupMappingResponse'] = _GETGROUPMAPPINGRESPONSE
DESCRIPTOR.message_types_by_name['CreateGroupMappingRequest'] = _CREATEGROUPMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['CreateGroupMappingMetadata'] = _CREATEGROUPMAPPINGMETADATA
DESCRIPTOR.message_types_by_name['UpdateGroupMappingRequest'] = _UPDATEGROUPMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['UpdateGroupMappingMetadata'] = _UPDATEGROUPMAPPINGMETADATA
DESCRIPTOR.message_types_by_name['DeleteGroupMappingRequest'] = _DELETEGROUPMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['DeleteGroupMappingMetadata'] = _DELETEGROUPMAPPINGMETADATA
DESCRIPTOR.message_types_by_name['UpdateGroupMappingItemsRequest'] = _UPDATEGROUPMAPPINGITEMSREQUEST
DESCRIPTOR.message_types_by_name['GroupMappingItemDelta'] = _GROUPMAPPINGITEMDELTA
DESCRIPTOR.message_types_by_name['UpdateGroupMappingItemsMetadata'] = _UPDATEGROUPMAPPINGITEMSMETADATA
DESCRIPTOR.message_types_by_name['UpdateGroupMappingItemsResponse'] = _UPDATEGROUPMAPPINGITEMSRESPONSE
DESCRIPTOR.message_types_by_name['ListGroupMappingItemsRequest'] = _LISTGROUPMAPPINGITEMSREQUEST
DESCRIPTOR.message_types_by_name['ListGroupMappingItemsResponse'] = _LISTGROUPMAPPINGITEMSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGroupMappingRequest = _reflection.GeneratedProtocolMessageType('GetGroupMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPMAPPINGREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GetGroupMappingRequest)
  })
_sym_db.RegisterMessage(GetGroupMappingRequest)

GetGroupMappingResponse = _reflection.GeneratedProtocolMessageType('GetGroupMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPMAPPINGRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GetGroupMappingResponse)
  })
_sym_db.RegisterMessage(GetGroupMappingResponse)

CreateGroupMappingRequest = _reflection.GeneratedProtocolMessageType('CreateGroupMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGROUPMAPPINGREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest)
  })
_sym_db.RegisterMessage(CreateGroupMappingRequest)

CreateGroupMappingMetadata = _reflection.GeneratedProtocolMessageType('CreateGroupMappingMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGROUPMAPPINGMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.CreateGroupMappingMetadata)
  })
_sym_db.RegisterMessage(CreateGroupMappingMetadata)

UpdateGroupMappingRequest = _reflection.GeneratedProtocolMessageType('UpdateGroupMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMAPPINGREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest)
  })
_sym_db.RegisterMessage(UpdateGroupMappingRequest)

UpdateGroupMappingMetadata = _reflection.GeneratedProtocolMessageType('UpdateGroupMappingMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMAPPINGMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMappingMetadata)
  })
_sym_db.RegisterMessage(UpdateGroupMappingMetadata)

DeleteGroupMappingRequest = _reflection.GeneratedProtocolMessageType('DeleteGroupMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGROUPMAPPINGREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteGroupMappingRequest)
  })
_sym_db.RegisterMessage(DeleteGroupMappingRequest)

DeleteGroupMappingMetadata = _reflection.GeneratedProtocolMessageType('DeleteGroupMappingMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGROUPMAPPINGMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteGroupMappingMetadata)
  })
_sym_db.RegisterMessage(DeleteGroupMappingMetadata)

UpdateGroupMappingItemsRequest = _reflection.GeneratedProtocolMessageType('UpdateGroupMappingItemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMAPPINGITEMSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest)
  })
_sym_db.RegisterMessage(UpdateGroupMappingItemsRequest)

GroupMappingItemDelta = _reflection.GeneratedProtocolMessageType('GroupMappingItemDelta', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMAPPINGITEMDELTA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GroupMappingItemDelta)
  })
_sym_db.RegisterMessage(GroupMappingItemDelta)

UpdateGroupMappingItemsMetadata = _reflection.GeneratedProtocolMessageType('UpdateGroupMappingItemsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMAPPINGITEMSMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsMetadata)
  })
_sym_db.RegisterMessage(UpdateGroupMappingItemsMetadata)

UpdateGroupMappingItemsResponse = _reflection.GeneratedProtocolMessageType('UpdateGroupMappingItemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMAPPINGITEMSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsResponse)
  })
_sym_db.RegisterMessage(UpdateGroupMappingItemsResponse)

ListGroupMappingItemsRequest = _reflection.GeneratedProtocolMessageType('ListGroupMappingItemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPMAPPINGITEMSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest)
  })
_sym_db.RegisterMessage(ListGroupMappingItemsRequest)

ListGroupMappingItemsResponse = _reflection.GeneratedProtocolMessageType('ListGroupMappingItemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPMAPPINGITEMSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse)
  })
_sym_db.RegisterMessage(ListGroupMappingItemsResponse)


DESCRIPTOR._options = None
_GETGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
_CREATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
_UPDATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
_UPDATEGROUPMAPPINGREQUEST.fields_by_name['updated_fields']._options = None
_DELETEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
_UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._options = None
_UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['group_mapping_item_deltas']._options = None
_LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._options = None
_LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_size']._options = None
_LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_token']._options = None
_LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['filter']._options = None

_GROUPMAPPINGSERVICE = _descriptor.ServiceDescriptor(
  name='GroupMappingService',
  full_name='yandex.cloud.organizationmanager.v1.GroupMappingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1820,
  serialized_end=2796,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.Get',
    index=0,
    containing_service=None,
    input_type=_GETGROUPMAPPINGREQUEST,
    output_type=_GETGROUPMAPPINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.Create',
    index=1,
    containing_service=None,
    input_type=_CREATEGROUPMAPPINGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322**\n\032CreateGroupMappingMetadata\022\014GroupMapping',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.Update',
    index=2,
    containing_service=None,
    input_type=_UPDATEGROUPMAPPINGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322**\n\032UpdateGroupMappingMetadata\022\014GroupMapping',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEGROUPMAPPINGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*3\n\032DeleteGroupMappingMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListItems',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.ListItems',
    index=4,
    containing_service=None,
    input_type=_LISTGROUPMAPPINGITEMSREQUEST,
    output_type=_LISTGROUPMAPPINGITEMSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateItems',
    full_name='yandex.cloud.organizationmanager.v1.GroupMappingService.UpdateItems',
    index=5,
    containing_service=None,
    input_type=_UPDATEGROUPMAPPINGITEMSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*B\n\037UpdateGroupMappingItemsMetadata\022\037UpdateGroupMappingItemsResponse',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUPMAPPINGSERVICE)

DESCRIPTOR.services_by_name['GroupMappingService'] = _GROUPMAPPINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/parametrization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/parametrization.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/monitoring/v3/parametrization.proto\x12\x1ayandex.cloud.monitoring.v3\x1a,yandex/cloud/monitoring/v3/unit_format.proto\"\x8f\x01\n\x14LabelValuesParameter\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tselectors\x18\x13 \x01(\t\x12\x11\n\tlabel_key\x18\x14 \x01(\t\x12\x17\n\x0fmultiselectable\x18\x15 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x16 \x03(\tB\x0b\n\tcontainer\"R\n\x0f\x43ustomParameter\x12\x0e\n\x06values\x18\x01 \x03(\t\x12\x17\n\x0fmultiselectable\x18\x02 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x03 \x03(\t\"&\n\rTextParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"e\n\x0f\x44oubleParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"f\n\x10IntegerParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"-\n\x13TextValuesParameter\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x01 \x03(\t\"\xf5\x03\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12H\n\x0clabel_values\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.monitoring.v3.LabelValuesParameterH\x00\x12=\n\x06\x63ustom\x18\x04 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.CustomParameterH\x00\x12\x39\n\x04text\x18\x05 \x01(\x0b\x32).yandex.cloud.monitoring.v3.TextParameterH\x00\x12I\n\x11integer_parameter\x18\x07 \x01(\x0b\x32,.yandex.cloud.monitoring.v3.IntegerParameterH\x00\x12G\n\x10\x64ouble_parameter\x18\x08 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.DoubleParameterH\x00\x12\x46\n\x0btext_values\x18\t \x01(\x0b\x32/.yandex.cloud.monitoring.v3.TextValuesParameterH\x00\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\tB\x06\n\x04\x64\x61ta\"_\n\x0fParametrization\x12\x39\n\nparameters\x18\x01 \x03(\x0b\x32%.yandex.cloud.monitoring.v3.Parameter\x12\x11\n\tselectors\x18\x02 \x01(\tBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2.DESCRIPTOR,])




_LABELVALUESPARAMETER = _descriptor.Descriptor(
  name='LabelValuesParameter',
  full_name='yandex.cloud.monitoring.v3.LabelValuesParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.folder_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectors', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.selectors', index=1,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_key', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.label_key', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiselectable', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.multiselectable', index=3,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.default_values', index=4,
      number=22, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='container', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.container',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127,
  serialized_end=270,
)


_CUSTOMPARAMETER = _descriptor.Descriptor(
  name='CustomParameter',
  full_name='yandex.cloud.monitoring.v3.CustomParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.monitoring.v3.CustomParameter.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiselectable', full_name='yandex.cloud.monitoring.v3.CustomParameter.multiselectable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.CustomParameter.default_values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=354,
)


_TEXTPARAMETER = _descriptor.Descriptor(
  name='TextParameter',
  full_name='yandex.cloud.monitoring.v3.TextParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.TextParameter.default_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=394,
)


_DOUBLEPARAMETER = _descriptor.Descriptor(
  name='DoubleParameter',
  full_name='yandex.cloud.monitoring.v3.DoubleParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.DoubleParameter.default_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_format', full_name='yandex.cloud.monitoring.v3.DoubleParameter.unit_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=497,
)


_INTEGERPARAMETER = _descriptor.Descriptor(
  name='IntegerParameter',
  full_name='yandex.cloud.monitoring.v3.IntegerParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.IntegerParameter.default_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_format', full_name='yandex.cloud.monitoring.v3.IntegerParameter.unit_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=601,
)


_TEXTVALUESPARAMETER = _descriptor.Descriptor(
  name='TextValuesParameter',
  full_name='yandex.cloud.monitoring.v3.TextValuesParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.TextValuesParameter.default_values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=648,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='yandex.cloud.monitoring.v3.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.Parameter.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_values', full_name='yandex.cloud.monitoring.v3.Parameter.label_values', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='yandex.cloud.monitoring.v3.Parameter.custom', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.monitoring.v3.Parameter.text', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer_parameter', full_name='yandex.cloud.monitoring.v3.Parameter.integer_parameter', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_parameter', full_name='yandex.cloud.monitoring.v3.Parameter.double_parameter', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_values', full_name='yandex.cloud.monitoring.v3.Parameter.text_values', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='yandex.cloud.monitoring.v3.Parameter.hidden', index=8,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.monitoring.v3.Parameter.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='yandex.cloud.monitoring.v3.Parameter.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=651,
  serialized_end=1152,
)


_PARAMETRIZATION = _descriptor.Descriptor(
  name='Parametrization',
  full_name='yandex.cloud.monitoring.v3.Parametrization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yandex.cloud.monitoring.v3.Parametrization.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectors', full_name='yandex.cloud.monitoring.v3.Parametrization.selectors', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1249,
)

_LABELVALUESPARAMETER.oneofs_by_name['container'].fields.append(
  _LABELVALUESPARAMETER.fields_by_name['folder_id'])
_LABELVALUESPARAMETER.fields_by_name['folder_id'].containing_oneof = _LABELVALUESPARAMETER.oneofs_by_name['container']
_DOUBLEPARAMETER.fields_by_name['unit_format'].enum_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2._UNITFORMAT
_INTEGERPARAMETER.fields_by_name['unit_format'].enum_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2._UNITFORMAT
_PARAMETER.fields_by_name['label_values'].message_type = _LABELVALUESPARAMETER
_PARAMETER.fields_by_name['custom'].message_type = _CUSTOMPARAMETER
_PARAMETER.fields_by_name['text'].message_type = _TEXTPARAMETER
_PARAMETER.fields_by_name['integer_parameter'].message_type = _INTEGERPARAMETER
_PARAMETER.fields_by_name['double_parameter'].message_type = _DOUBLEPARAMETER
_PARAMETER.fields_by_name['text_values'].message_type = _TEXTVALUESPARAMETER
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['label_values'])
_PARAMETER.fields_by_name['label_values'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['custom'])
_PARAMETER.fields_by_name['custom'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['text'])
_PARAMETER.fields_by_name['text'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['integer_parameter'])
_PARAMETER.fields_by_name['integer_parameter'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['double_parameter'])
_PARAMETER.fields_by_name['double_parameter'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['text_values'])
_PARAMETER.fields_by_name['text_values'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETRIZATION.fields_by_name['parameters'].message_type = _PARAMETER
DESCRIPTOR.message_types_by_name['LabelValuesParameter'] = _LABELVALUESPARAMETER
DESCRIPTOR.message_types_by_name['CustomParameter'] = _CUSTOMPARAMETER
DESCRIPTOR.message_types_by_name['TextParameter'] = _TEXTPARAMETER
DESCRIPTOR.message_types_by_name['DoubleParameter'] = _DOUBLEPARAMETER
DESCRIPTOR.message_types_by_name['IntegerParameter'] = _INTEGERPARAMETER
DESCRIPTOR.message_types_by_name['TextValuesParameter'] = _TEXTVALUESPARAMETER
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['Parametrization'] = _PARAMETRIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelValuesParameter = _reflection.GeneratedProtocolMessageType('LabelValuesParameter', (_message.Message,), {
  'DESCRIPTOR' : _LABELVALUESPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.LabelValuesParameter)
  })
_sym_db.RegisterMessage(LabelValuesParameter)

CustomParameter = _reflection.GeneratedProtocolMessageType('CustomParameter', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.CustomParameter)
  })
_sym_db.RegisterMessage(CustomParameter)

TextParameter = _reflection.GeneratedProtocolMessageType('TextParameter', (_message.Message,), {
  'DESCRIPTOR' : _TEXTPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TextParameter)
  })
_sym_db.RegisterMessage(TextParameter)

DoubleParameter = _reflection.GeneratedProtocolMessageType('DoubleParameter', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.DoubleParameter)
  })
_sym_db.RegisterMessage(DoubleParameter)

IntegerParameter = _reflection.GeneratedProtocolMessageType('IntegerParameter', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.IntegerParameter)
  })
_sym_db.RegisterMessage(IntegerParameter)

TextValuesParameter = _reflection.GeneratedProtocolMessageType('TextValuesParameter', (_message.Message,), {
  'DESCRIPTOR' : _TEXTVALUESPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TextValuesParameter)
  })
_sym_db.RegisterMessage(TextValuesParameter)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

Parametrization = _reflection.GeneratedProtocolMessageType('Parametrization', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETRIZATION,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Parametrization)
  })
_sym_db.RegisterMessage(Parametrization)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/cloud_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.resourcemanager.v1 import cloud_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/resourcemanager/v1/cloud_service.proto',
  package='yandex.cloud.resourcemanager.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/resourcemanager/v1/cloud_service.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+yandex/cloud/resourcemanager/v1/cloud.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x91\x01\n\x11ListCloudsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\x0forganization_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"e\n\x12ListCloudsResponse\x12\x36\n\x06\x63louds\x18\x01 \x03(\x0b\x32&.yandex.cloud.resourcemanager.v1.Cloud\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x02\n\x12\x43reateCloudRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13\x43reateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"{\n\x1aListCloudOperationsRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"m\n\x1bListCloudOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xfa\x02\n\x12UpdateCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x04name\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x05 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13UpdateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"f\n\x12\x44\x65leteCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Y\n\x13\x44\x65leteCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe8\r\n\x0c\x43loudService\x12\x8f\x01\n\x03Get\x12\x30.yandex.cloud.resourcemanager.v1.GetCloudRequest\x1a&.yandex.cloud.resourcemanager.v1.Cloud\".\x82\xd3\xe4\x93\x02(\x12&/resource-manager/v1/clouds/{cloud_id}\x12\x94\x01\n\x04List\x12\x32.yandex.cloud.resourcemanager.v1.ListCloudsRequest\x1a\x33.yandex.cloud.resourcemanager.v1.ListCloudsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/resource-manager/v1/clouds\x12\xa8\x01\n\x06\x43reate\x12\x33.yandex.cloud.resourcemanager.v1.CreateCloudRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02 \"\x1b/resource-manager/v1/clouds:\x01*\xb2\xd2*\x1c\n\x13\x43reateCloudMetadata\x12\x05\x43loud\x12\xb3\x01\n\x06Update\x12\x33.yandex.cloud.resourcemanager.v1.UpdateCloudRequest\x1a!.yandex.cloud.operation.Operation\"Q\x82\xd3\xe4\x93\x02+2&/resource-manager/v1/clouds/{cloud_id}:\x01*\xb2\xd2*\x1c\n\x13UpdateCloudMetadata\x12\x05\x43loud\x12\xc0\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.resourcemanager.v1.DeleteCloudRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02(*&/resource-manager/v1/clouds/{cloud_id}\xb2\xd2*,\n\x13\x44\x65leteCloudMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x0eListOperations\x12;.yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest\x1a<.yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/resource-manager/v1/clouds/{cloud_id}/operations\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</resource-manager/v1/clouds/{resource_id}:listAccessBindings\x12\xfa\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\x82\xd3\xe4\x93\x02@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\x01*\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x12\x86\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x98\x01\x82\xd3\xe4\x93\x02\x43\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResultBz\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETCLOUDREQUEST = _descriptor.Descriptor(
  name='GetCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.GetCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.GetCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=418,
)


_LISTCLOUDSREQUEST = _descriptor.Descriptor(
  name='ListCloudsRequest',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.organization_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=566,
)


_LISTCLOUDSRESPONSE = _descriptor.Descriptor(
  name='ListCloudsResponse',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clouds', full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse.clouds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=669,
)


_CREATECLOUDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1010,
)

_CREATECLOUDREQUEST = _descriptor.Descriptor(
  name='CreateCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECLOUDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=1010,
)


_CREATECLOUDMETADATA = _descriptor.Descriptor(
  name='CreateCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.CreateCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1051,
)


_LISTCLOUDOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListCloudOperationsRequest',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1176,
)


_LISTCLOUDOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListCloudOperationsResponse',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1287,
)


_UPDATECLOUDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1010,
)

_UPDATECLOUDREQUEST = _descriptor.Descriptor(
  name='UpdateCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECLOUDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1668,
)


_UPDATECLOUDMETADATA = _descriptor.Descriptor(
  name='UpdateCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1709,
)


_DELETECLOUDREQUEST = _descriptor.Descriptor(
  name='DeleteCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_after', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest.delete_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1813,
)


_DELETECLOUDMETADATA = _descriptor.Descriptor(
  name='DeleteCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_after', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata.delete_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1904,
)

_LISTCLOUDSRESPONSE.fields_by_name['clouds'].message_type = yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2._CLOUD
_CREATECLOUDREQUEST_LABELSENTRY.containing_type = _CREATECLOUDREQUEST
_CREATECLOUDREQUEST.fields_by_name['labels'].message_type = _CREATECLOUDREQUEST_LABELSENTRY
_LISTCLOUDOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_UPDATECLOUDREQUEST_LABELSENTRY.containing_type = _UPDATECLOUDREQUEST
_UPDATECLOUDREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECLOUDREQUEST.fields_by_name['labels'].message_type = _UPDATECLOUDREQUEST_LABELSENTRY
_DELETECLOUDREQUEST.fields_by_name['delete_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETECLOUDMETADATA.fields_by_name['delete_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetCloudRequest'] = _GETCLOUDREQUEST
DESCRIPTOR.message_types_by_name['ListCloudsRequest'] = _LISTCLOUDSREQUEST
DESCRIPTOR.message_types_by_name['ListCloudsResponse'] = _LISTCLOUDSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCloudRequest'] = _CREATECLOUDREQUEST
DESCRIPTOR.message_types_by_name['CreateCloudMetadata'] = _CREATECLOUDMETADATA
DESCRIPTOR.message_types_by_name['ListCloudOperationsRequest'] = _LISTCLOUDOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCloudOperationsResponse'] = _LISTCLOUDOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCloudRequest'] = _UPDATECLOUDREQUEST
DESCRIPTOR.message_types_by_name['UpdateCloudMetadata'] = _UPDATECLOUDMETADATA
DESCRIPTOR.message_types_by_name['DeleteCloudRequest'] = _DELETECLOUDREQUEST
DESCRIPTOR.message_types_by_name['DeleteCloudMetadata'] = _DELETECLOUDMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCloudRequest = _reflection.GeneratedProtocolMessageType('GetCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.GetCloudRequest)
  })
_sym_db.RegisterMessage(GetCloudRequest)

ListCloudsRequest = _reflection.GeneratedProtocolMessageType('ListCloudsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudsRequest)
  })
_sym_db.RegisterMessage(ListCloudsRequest)

ListCloudsResponse = _reflection.GeneratedProtocolMessageType('ListCloudsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSRESPONSE,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudsResponse)
  })
_sym_db.RegisterMessage(ListCloudsResponse)

CreateCloudRequest = _reflection.GeneratedProtocolMessageType('CreateCloudRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECLOUDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudRequest)
  })
_sym_db.RegisterMessage(CreateCloudRequest)
_sym_db.RegisterMessage(CreateCloudRequest.LabelsEntry)

CreateCloudMetadata = _reflection.GeneratedProtocolMessageType('CreateCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudMetadata)
  })
_sym_db.RegisterMessage(CreateCloudMetadata)

ListCloudOperationsRequest = _reflection.GeneratedProtocolMessageType('ListCloudOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest)
  })
_sym_db.RegisterMessage(ListCloudOperationsRequest)

ListCloudOperationsResponse = _reflection.GeneratedProtocolMessageType('ListCloudOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse)
  })
_sym_db.RegisterMessage(ListCloudOperationsResponse)

UpdateCloudRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECLOUDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudRequest)
  })
_sym_db.RegisterMessage(UpdateCloudRequest)
_sym_db.RegisterMessage(UpdateCloudRequest.LabelsEntry)

UpdateCloudMetadata = _reflection.GeneratedProtocolMessageType('UpdateCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudMetadata)
  })
_sym_db.RegisterMessage(UpdateCloudMetadata)

DeleteCloudRequest = _reflection.GeneratedProtocolMessageType('DeleteCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.DeleteCloudRequest)
  })
_sym_db.RegisterMessage(DeleteCloudRequest)

DeleteCloudMetadata = _reflection.GeneratedProtocolMessageType('DeleteCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.DeleteCloudMetadata)
  })
_sym_db.RegisterMessage(DeleteCloudMetadata)


DESCRIPTOR._options = None
_GETCLOUDREQUEST.fields_by_name['cloud_id']._options = None
_LISTCLOUDSREQUEST.fields_by_name['page_size']._options = None
_LISTCLOUDSREQUEST.fields_by_name['page_token']._options = None
_LISTCLOUDSREQUEST.fields_by_name['filter']._options = None
_LISTCLOUDSREQUEST.fields_by_name['organization_id']._options = None
_CREATECLOUDREQUEST_LABELSENTRY._options = None
_CREATECLOUDREQUEST.fields_by_name['organization_id']._options = None
_CREATECLOUDREQUEST.fields_by_name['name']._options = None
_CREATECLOUDREQUEST.fields_by_name['description']._options = None
_CREATECLOUDREQUEST.fields_by_name['labels']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['cloud_id']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_UPDATECLOUDREQUEST_LABELSENTRY._options = None
_UPDATECLOUDREQUEST.fields_by_name['cloud_id']._options = None
_UPDATECLOUDREQUEST.fields_by_name['name']._options = None
_UPDATECLOUDREQUEST.fields_by_name['description']._options = None
_UPDATECLOUDREQUEST.fields_by_name['labels']._options = None
_DELETECLOUDREQUEST.fields_by_name['cloud_id']._options = None

_CLOUDSERVICE = _descriptor.ServiceDescriptor(
  name='CloudService',
  full_name='yandex.cloud.resourcemanager.v1.CloudService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1907,
  serialized_end=3675,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2._CLOUD,
    serialized_options=b'\202\323\344\223\002(\022&/resource-manager/v1/clouds/{cloud_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCLOUDSREQUEST,
    output_type=_LISTCLOUDSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/resource-manager/v1/clouds',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 \"\033/resource-manager/v1/clouds:\001*\262\322*\034\n\023CreateCloudMetadata\022\005Cloud',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+2&/resource-manager/v1/clouds/{cloud_id}:\001*\262\322*\034\n\023UpdateCloudMetadata\022\005Cloud',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(*&/resource-manager/v1/clouds/{cloud_id}\262\322*,\n\023DeleteCloudMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTCLOUDOPERATIONSREQUEST,
    output_type=_LISTCLOUDOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/resource-manager/v1/clouds/{cloud_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</resource-manager/v1/clouds/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\001*\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\001*\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLOUDSERVICE)

DESCRIPTOR.services_by_name['CloudService'] = _CLOUDSERVICE

# @@protoc_insertion_point(module_scope)
